<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AboutPreferences</name>
    <message>
        <location filename="../src/ui/qml/AboutPreferences.qml" line="14"/>
        <source>Ricochet %1</source>
        <extracomment>%1 version, e.g. 1.0.0</extracomment>
        <translation>Ricochet %1</translation>
    </message>
</context>
<context>
    <name>AddContactDialog</name>
    <message>
        <location filename="../src/ui/qml/AddContactDialog.qml" line="51"/>
        <source>Share your Ricochet ID to allow connection requests</source>
        <translation>Сообщите свой ID, чтобы собеседник узнал Вас</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/AddContactDialog.qml" line="107"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/AddContactDialog.qml" line="112"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
</context>
<context>
    <name>ContactActions</name>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="40"/>
        <source>Open Window</source>
        <translation>Открыть окно</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="44"/>
        <source>Details...</source>
        <translation>Подробнее...</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="48"/>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactActions.qml" line="53"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>ContactIDField</name>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="41"/>
        <source>&lt;b&gt;%1&lt;/b&gt; is already your contact</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; уже в Вашем списке контактов</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="43"/>
        <source>You can&apos;t add yourself as a contact</source>
        <translation>Вы не можете добавить себя в свой же список контактов</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="45"/>
        <source>Enter an ID starting with &lt;b&gt;ricochet:&lt;/b&gt;</source>
        <translation>Введите ID, начинающийся с &lt;b&gt;ricochet:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="81"/>
        <source>Copied to clipboard</source>
        <translation>Скопировано в буфер</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactIDField.qml" line="93"/>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
</context>
<context>
    <name>ContactList</name>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="76"/>
        <source>Online</source>
        <translation>В сети</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="77"/>
        <source>Offline</source>
        <translation>Не в сети</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="78"/>
        <source>Requests</source>
        <translation>Запросы</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="79"/>
        <source>Rejected</source>
        <translation>Отказано</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactList.qml" line="80"/>
        <source>Outdated</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ContactPreferences</name>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="98"/>
        <source>Date added:</source>
        <translation>Добавлен:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="106"/>
        <source>Last seen:</source>
        <translation>Последний раз замечен:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="116"/>
        <source>Request:</source>
        <translation>Запрос:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="126"/>
        <source>Pending connection</source>
        <translation>Ожидаем соединение</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="127"/>
        <source>Delivered</source>
        <translation>Доставлено</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="128"/>
        <source>Accepted</source>
        <translation>Принято</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="129"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="130"/>
        <source>Rejected</source>
        <translation>Отказано</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="134"/>
        <source>%1 (Connected)</source>
        <extracomment>%1 status, e.g. &quot;Accepted&quot;</extracomment>
        <translation>%1 (Соединено)</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="140"/>
        <source>Response:</source>
        <translation>Ответ:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="163"/>
        <source>Rename</source>
        <translation type="unfinished">Переименовать</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactPreferences.qml" line="170"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>ContactRequestDialog</name>
    <message>
        <location filename="../src/ui/qml/ContactRequestDialog.qml" line="55"/>
        <source>Someone new is asking to connect to you</source>
        <translation>Новый человек хочет пообщаться с Вами</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestDialog.qml" line="102"/>
        <source>Reject</source>
        <translation>Отказать</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestDialog.qml" line="107"/>
        <source>Accept</source>
        <translation>Принять</translation>
    </message>
</context>
<context>
    <name>ContactRequestFields</name>
    <message>
        <location filename="../src/ui/qml/ContactRequestFields.qml" line="17"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestFields.qml" line="29"/>
        <source>Name:</source>
        <translation>Имя:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/ContactRequestFields.qml" line="40"/>
        <source>Message:</source>
        <translation>Сообщение:</translation>
    </message>
</context>
<context>
    <name>GeneralPreferences</name>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="13"/>
        <source>Use a single window for conversations</source>
        <translation>Использовать одно окно для разговоров</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="21"/>
        <source>Open links in default browser without prompting</source>
        <translation>Открывать ссылки в браузере по умолчанию без запроса</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="29"/>
        <source>Play audio notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="38"/>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="53"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/GeneralPreferences.qml" line="76"/>
        <source>Restart Ricochet to apply changes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LanguagesModel</name>
    <message>
        <location filename="../src/ui/LanguagesModel.cpp" line="43"/>
        <source>System default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../src/main.cpp" line="81"/>
        <source>Ricochet Error</source>
        <translation>Ошибка Ricochet</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <location filename="../src/ui/qml/MainToolBar.qml" line="19"/>
        <source>Add Contact</source>
        <translation>Добавить контакт</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MainToolBar.qml" line="28"/>
        <source>Preferences</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MainToolBar.qml" line="75"/>
        <source>Click to add contacts</source>
        <translation>Нажмите, чтобы добавить контакты</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/ui/MainWindow.cpp" line="191"/>
        <source>Remove %1</source>
        <translation>Удалить %1</translation>
    </message>
    <message>
        <location filename="../src/ui/MainWindow.cpp" line="192"/>
        <source>Do you want to permanently remove %1?</source>
        <translation>Вы действительно хотите удалить %1 навсегда?</translation>
    </message>
</context>
<context>
    <name>MessageDelegate</name>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="26"/>
        <source>%1 is offline</source>
        <extracomment>%1 nickname</extracomment>
        <translation>%1 не в сети</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="135"/>
        <source>Copy ID</source>
        <translation>Копировать ID</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="135"/>
        <source>Copy Link</source>
        <translation>Копировать ссылку</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="140"/>
        <source>Open with Browser</source>
        <translation>Открыть в браузере</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="154"/>
        <source>Add as Contact</source>
        <translation>Добавить в список контактов</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="166"/>
        <source>Copy Message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDelegate.qml" line="173"/>
        <source>Copy Selection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageDialogWrapper</name>
    <message>
        <location filename="../src/ui/qml/MessageDialogWrapper.qml" line="8"/>
        <source>Remove %1</source>
        <translation>Удалить %1</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDialogWrapper.qml" line="10"/>
        <source>Do you want to permanently remove %1?</source>
        <extracomment>%1 nickname</extracomment>
        <translation>Вы действительно хотите удалить %1 навсегда?</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/MessageDialogWrapper.qml" line="11"/>
        <source>This contact will no longer be able to message you, and will be notified about the removal. They may choose to send a new connection request.</source>
        <translation>Этот контакт больше не сможет писать Вам и будет уведомлен об удалении. Тем не менее, он сможет послать Вам новый запрос.</translation>
    </message>
</context>
<context>
    <name>NetworkSetupWizard</name>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="100"/>
        <source>This computer&apos;s Internet connection is free of obstacles. I would like to connect directly to the Tor network.</source>
        <translation>Соединение на этом компьютере свободно от цензуры и фильтров. Я хочу подключиться к сети Tor напрямую.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="107"/>
        <source>Connect</source>
        <translation>Соединиться</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="124"/>
        <source>This computer&apos;s Internet connection is censored, filtered, or proxied. I need to configure network settings.</source>
        <translation>Соединение на этом компьютере подвергается цензуре, фильтрации либо проксируется. Мне нужно настроить дополнительные параметры соединения.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/NetworkSetupWizard.qml" line="131"/>
        <source>Configure</source>
        <translation>Настроить</translation>
    </message>
</context>
<context>
    <name>OfflineStateItem</name>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="107"/>
        <source>Configure</source>
        <translation>Настроить</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="115"/>
        <source>Details</source>
        <translation>Подробности</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="143"/>
        <source>Connection failed</source>
        <translation>Не удалось соединиться</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OfflineStateItem.qml" line="169"/>
        <source>Connecting…</source>
        <extracomment>\u2026 is ellipsis</extracomment>
        <translation>Соединение...</translation>
    </message>
</context>
<context>
    <name>OpenBrowserDialog</name>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="40"/>
        <source>&lt;b&gt;Warning!&lt;/b&gt; Opening links with your default browser will harm your security and anonymity.&lt;br&gt;&lt;br&gt;You can &lt;a href=&apos;.&apos;&gt;copy to the clipboard&lt;/a&gt; instead.</source>
        <translation>&lt;b&gt;Внимание!&lt;/b&gt; Открывая ссылки браузером по умолчанию Вы можете нарушить Вашу безопасность и анонимность.&lt;br&gt;&lt;br&gt;Вместо этого Вы можете &lt;a href=&apos;.&apos;&gt;скопировать ссылку&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="59"/>
        <source>Don&apos;t ask again for links from %1</source>
        <translation>Не спрашивать при открытии последующих ссылок от %1</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="65"/>
        <source>Don&apos;t ask again for any links (not recommended!)</source>
        <translation>Не спрашивать при открытии всех последующих ссылок (не рекомендуется!)</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="72"/>
        <source>Open Browser</source>
        <translation>Открыть браузер</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/OpenBrowserDialog.qml" line="84"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="12"/>
        <source>Ricochet Preferences</source>
        <translation>Настройки Ricochet</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="41"/>
        <source>General</source>
        <translation>Основные</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="46"/>
        <source>Contacts</source>
        <translation>Контакты</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="51"/>
        <source>Tor</source>
        <translation>Tor</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/PreferencesDialog.qml" line="56"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
</context>
<context>
    <name>QCocoaMenuItem</name>
    <message>
        <location filename="../src/ui/qml/MainWindow.qml" line="29"/>
        <source>Preference</source>
        <translation>Настройки</translation>
    </message>
</context>
<context>
    <name>StartupStatusPage</name>
    <message>
        <location filename="../src/ui/qml/StartupStatusPage.qml" line="18"/>
        <source>The Tor process was not started successfully. This is most likely an installation or system error.</source>
        <translation>Процесс Tor не был запущен успешно. Скорее всего, причина в неправильной установке или системной ошибке.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/StartupStatusPage.qml" line="49"/>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
</context>
<context>
    <name>TorBootstrapStatus</name>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="17"/>
        <source>Connecting to the Tor network…</source>
        <extracomment>\u2026 is ellipsis</extracomment>
        <translation>Подсоединяемся к сети Tor…</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="51"/>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="58"/>
        <source>Hide details</source>
        <translation>Скрыть подробности</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="58"/>
        <source>Show details</source>
        <translation>Показать подробности</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorBootstrapStatus.qml" line="70"/>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
</context>
<context>
    <name>TorConfigurationPage</name>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="73"/>
        <source>Does this computer need a proxy to access the internet?</source>
        <translation>Этот компьютер использует прокси для доступа в Интернет?</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="85"/>
        <source>Proxy type:</source>
        <translation>Тип прокси:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="90"/>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="92"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="107"/>
        <source>Address:</source>
        <translation>Адрес:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="116"/>
        <source>IP address or hostname</source>
        <translation>IP адрес или имя хоста</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="119"/>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="130"/>
        <source>Username:</source>
        <translation>Имя пользователя:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="140"/>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="150"/>
        <source>Optional</source>
        <translation>Необязательно</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="143"/>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="160"/>
        <source>Does this computer&apos;s Internet connection go through a firewall that only allows connections to certain ports?</source>
        <translation>Соединение данного компьютера фильтруется фаерволом, который разрешает доступ только к определенным портам?</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="171"/>
        <source>Allowed ports:</source>
        <translation>Открытые порты:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="178"/>
        <source>Example: 80,443</source>
        <translation>Например: 80,443</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="189"/>
        <source>If this computer&apos;s Internet connection is censored, you will need to obtain and use bridge relays.</source>
        <translation>Если соединение этого компьютера подвергается цензуре, Вам необходимо получить и использовать ретрансляторы Tor.</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="198"/>
        <source>Enter one or more bridge relays (one per line):</source>
        <translation>Введите один ретранслятор или более (по одному на строку):</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="213"/>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorConfigurationPage.qml" line="220"/>
        <source>Connect</source>
        <translation>Соединить</translation>
    </message>
</context>
<context>
    <name>TorPreferences</name>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="25"/>
        <source>Running:</source>
        <translation>Запущен:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="26"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="28"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="30"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="26"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="28"/>
        <location filename="../src/ui/qml/TorPreferences.qml" line="30"/>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="26"/>
        <source>External</source>
        <translation>Внешний</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="27"/>
        <source>Control connected:</source>
        <translation>Контроль присоединенных:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="29"/>
        <source>Circuits established:</source>
        <translation>Цепи установлены:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="31"/>
        <source>Hidden service:</source>
        <translation>Скрытый сервис:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="32"/>
        <source>Online</source>
        <translation>В сети</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="32"/>
        <source>Offline</source>
        <translation>Не в сети</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="33"/>
        <source>Version:</source>
        <translation>Версия:</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="60"/>
        <source>Error: &lt;b&gt;%1&lt;/b&gt;</source>
        <extracomment>%1 is error message</extracomment>
        <translation>Ошибка: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorPreferences.qml" line="76"/>
        <source>Configure</source>
        <translation>Настроить</translation>
    </message>
</context>
<context>
    <name>TorStateWidget</name>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="9"/>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="20"/>
        <source>Connection failed</source>
        <translation>Не удалось соединиться</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="12"/>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="22"/>
        <source>Connecting…</source>
        <extracomment>\u2026 is ellipsis</extracomment>
        <translation>Соединение…</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="25"/>
        <source>Connecting… (%1%)</source>
        <extracomment>%1 is progress percentage, e.g. 100</extracomment>
        <translation>Соединение… (%1%)</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="32"/>
        <source>Online</source>
        <translation>В сети</translation>
    </message>
    <message>
        <location filename="../src/ui/qml/TorStateWidget.qml" line="34"/>
        <source>Connected</source>
        <translation>Соединено</translation>
    </message>
</context>
</TS>
